@@ -1,7 +1,8 @@
 import typer
 
 import os
-os.system('export PYTHONPATH=.')
+pwd = "/".join(__file__.split("/")[:-1])
+os.system("export PYTHONPATH="+pwd)
 
 import lib.wifi as wifi
 import lib.bt as bt
